@@ -1,5 +1,6 @@
 from PyQt6 import QtCore, QtGui, QtWidgets   
-import MainWindow, ConnectionConfigurationDialog, DatabaseMYSQL, Plot
+from ticsummary import MainWindow, ConnectionConfigurationDialog, DatabaseMYSQL, Plot
+
 
 class EntryPoint:
     sqlParameters:DatabaseMYSQL.ParameterConnection
